@@ -202,6 +202,10 @@ class Base(abc.ABC):
     def get_enable_strict_override_check(self) -> Optional[bool]:
         raise NotImplementedError()
 
+    @abc.abstractmethod
+    def get_enable_strict_any_check(self) -> Optional[bool]:
+        raise NotImplementedError()
+
     @abc.abstractmethod
     def get_enable_unawaited_awaitable_analysis(self) -> Optional[bool]:
         raise NotImplementedError()
@@ -214,10 +218,6 @@ class Base(abc.ABC):
     def get_include_suppressed_errors(self) -> Optional[bool]:
         raise NotImplementedError()
 
-    @abc.abstractmethod
-    def get_use_errpy_parser(self) -> bool:
-        raise NotImplementedError()
-
     def get_local_root(self) -> Optional[Path]:
         relative_local_root = self.get_relative_local_root()
         if relative_local_root is None:
@@ -403,6 +403,9 @@ class OpenSource(Base):
     def get_enable_strict_override_check(self) -> Optional[bool]:
         return self.configuration.enable_strict_override_check
 
+    def get_enable_strict_any_check(self) -> Optional[bool]:
+        return self.configuration.enable_strict_any_check
+
     def get_enable_unawaited_awaitable_analysis(self) -> Optional[bool]:
         return self.configuration.enable_unawaited_awaitable_analysis
 
@@ -414,6 +417,3 @@ class OpenSource(Base):
 
     def get_include_suppressed_errors(self) -> Optional[bool]:
         return self.configuration.include_suppressed_errors
-
-    def get_use_errpy_parser(self) -> bool:
-        return self.configuration.use_errpy_parser
